﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Infragistics.Web.Mvc;
using igGrid_GridModel.Models;

namespace igGrid_GridModel.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            ViewBag.Message = "Welcome to ASP.NET MVC!";
            // The View accepts GridModel model
            return View(this.GetGridModel());
        }

        public ActionResult About()
        {
            return View();
        }

        /*
         * This method will be called with an AJAX call from the grid after it is constructed in the browser
         * Use the helper method GridModel.GetData() which will format the JSON according to the grid requirements (basically grid needs some Metadata in order to handle for example date columns correctly)
         * Use GridModel.DataSource to pass IQueryable/DataSet/DataTable to the GridModel. IQueryable is the recommended, because it supports all the grid functionality. DataSet/DataTable have some restrictions (Ref: http://help.infragistics.com/NetAdvantage/jQuery/2012.2/CLR4.0?page=igGrid_Binding_to_DataTable.html)
         */
        public JsonResult GetData(int pageSize, int page)
        {
            GridModel gridModel = GetGridModel();
            // put your data in the data source
            // for example:gridModel.DataSource = GetList(pageSize, pageIndex).AsQueryable();
            gridModel.DataSource = this.GetProducts(pageSize, page).AsQueryable();
            return gridModel.GetData();
        }

        /*
         * Dynamically construct the grid configuration
         * 
         */
        private GridModel GetGridModel()
        {
            GridModel gridModel = new GridModel();
            gridModel.DataSourceUrl = Url.Action("GetData");
            gridModel.AutoGenerateColumns = false;
            gridModel.Columns.Add(new GridColumn()
            {
                Key = "ProductID",
                HeaderText = "ProductID",
                DataType = "number"
            });
            gridModel.Columns.Add(new GridColumn()
            {
                Key = "Name",
                HeaderText = "Name"
            });
            gridModel.Columns.Add(new GridColumn()
            {
                Key = "ProductNumber",
                HeaderText = "ProductNumber"
            });
            gridModel.Features.Add(new CustomGridPaging()
            {
                Type = OpType.Remote,
                PageSize = 5,
                CustomTotalRecordsCount = 200
            });
            return gridModel;
        }

        // Sample data
        private IEnumerable<Product> GetProducts(int pageSize, int page)
        {
            List<Product> products = new List<Product>()
        {
            new Product() { ProductID = 1, Name = "Adjustable Race", ProductNumber = "AR-5381" },
            new Product() { ProductID = 2, Name = "Bearing Ball", ProductNumber = "BA-8327" },
            new Product() { ProductID = 3, Name = "BB Ball Bearing", ProductNumber = "BE-2349" },
            new Product() { ProductID = 4, Name = "Headset Ball Bearings", ProductNumber = "BE-2908" },
            new Product() { ProductID = 316, Name = "Blade", ProductNumber = "BL-2036" },
            new Product() { ProductID = 317, Name = "LL Crankarm", ProductNumber = "CA-5965" },
            new Product() { ProductID = 318, Name = "ML Crankarm", ProductNumber = "CA-6738" },
            new Product() { ProductID = 319, Name = "HL Crankarm", ProductNumber = "CA-7457" },
            new Product() { ProductID = 320, Name = "Chainring Bolts", ProductNumber = "CB-2903" },
            new Product() { ProductID = 321, Name = "Chainring Nut", ProductNumber = "CN-6137" }
        };

            return products.Skip(pageSize * page).Take(pageSize);
        }
    }
}
